@@ -1,5 +1,5 @@
 //STARTHEADER
-// $Id: fastjet_timing_plugins.cc 2806 2011-12-01 17:21:00Z salam $
+// $Id: fastjet_timing_plugins.cc 3209 2013-09-15 20:03:30Z salam $
 //
 // Copyright (c) 2005-2011, Matteo Cacciari, Gavin P. Salam and Gregory Soyez
 //
@@ -303,7 +303,11 @@ int main (int argc, char ** argv) {
   bool   get_all_dij   = cmdline.present("-get-all-dij");
   bool   get_all_yij   = cmdline.present("-get-all-yij");
   double subdcut = cmdline.double_val("-subdcut",-1.0);
-  double etamax = cmdline.double_val("-etamax",1.0e305);
+  double rapmax = cmdline.double_val("-rapmax",1.0e305);
+  if (cmdline.present("-etamax")) {
+    cerr << "WARNING: -etamax options actually sets maximum rapidity (and overrides -rapmax)\n";
+    rapmax = cmdline.double_val("-etamax");
+  }
   bool   show_constituents = cmdline.present("-const");
   bool   massless = cmdline.present("-massless");
   int    nev     = cmdline.int_val("-nev",1);
@@ -413,7 +417,7 @@ int main (int argc, char ** argv) {
                                       max_iterations, overlap_threshold,
                                       sm_scale)));
 #else  // FASTJET_ENABLE_PLUGIN_CDFCONES
-    is_unavailable("midpoint");
+    is_unavailable("MidPoint");
 #endif // FASTJET_ENABLE_PLUGIN_CDFCONES
   } 
   if (all_algs || cmdline.present("-pxcone")) {
@@ -423,7 +427,7 @@ int main (int argc, char ** argv) {
                                       ktR, min_jet_energy,
                                       overlap_threshold)));
 #else  // FASTJET_ENABLE_PLUGIN_PXCONE
-    is_unavailable("pxcone");
+    is_unavailable("PxCone");
 #endif // FASTJET_ENABLE_PLUGIN_PXCONE
   } 
   if (all_algs || cmdline.present("-jetclu")) {
@@ -431,7 +435,7 @@ int main (int argc, char ** argv) {
     jet_defs.push_back( fj::JetDefinition( new fj::CDFJetCluPlugin (
                                                                     ktR, overlap_threshold, seed_threshold)));
 #else  // FASTJET_ENABLE_PLUGIN_CDFCONES
-    is_unavailable("pxcone");
+    is_unavailable("JetClu");
 #endif // FASTJET_ENABLE_PLUGIN_CDFCONES
   } 
   if (all_algs || cmdline.present("-siscone") || cmdline.present("-sisconespheri")) {
@@ -459,7 +463,7 @@ int main (int argc, char ** argv) {
       jet_defs.push_back( fj::JetDefinition(plugin));
     }
 #else  // FASTJET_ENABLE_PLUGIN_SISCONE
-    is_unavailable("siscone");
+    is_unavailable("SISCone");
 #endif // FASTJET_ENABLE_PLUGIN_SISCONE
   } 
   if (all_algs || cmdline.present("-d0runiicone")) {
@@ -509,7 +513,7 @@ int main (int argc, char ** argv) {
 #ifdef FASTJET_ENABLE_PLUGIN_D0RUNICONE
     jet_defs.push_back( fj::JetDefinition(new fj::D0RunIpre96ConePlugin(ktR, seed_threshold, overlap_threshold)));
 #else  // FASTJET_ENABLE_PLUGIN_D0RUNICONE
-    is_unavailable("D0RunICone");
+    is_unavailable("D0RunIpre96Cone");
 #endif // FASTJET_ENABLE_PLUGIN_D0RUNICONE
   } 
   if (all_algs || cmdline.present("-d0runicone")) {
@@ -590,7 +594,7 @@ int main (int argc, char ** argv) {
       }
     }
     fj::PseudoJet psjet(fourvec);
-    if (abs(psjet.rap() < etamax)) {particles.push_back(psjet);}
+    if (abs(psjet.rap()) < rapmax) {particles.push_back(psjet);}
   }
 
   // add a fake underlying event which is very soft, uniformly distributed
@@ -710,6 +714,8 @@ int main (int argc, char ** argv) {
     if (show_cones) {
       const fj::SISConeExtras * extras = 
         dynamic_cast<const fj::SISConeExtras *>(clust_seq->extras());
+      if (extras == 0) 
+        throw fastjet::Error("extras object for SISCone was null (this can happen with certain area types)");
       cout << "most ambiguous split (difference in squared dist) = "
            << extras->most_ambiguous_split() << endl;
       vector<fastjet::PseudoJet> stable_cones(extras->stable_cones()); 
