@@ -1,5 +1,5 @@
 //STARTHEADER
-// $Id: Selector.cc 2687 2011-11-14 11:17:51Z soyez $
+// $Id: Selector.cc 3071 2013-04-01 12:52:46Z cacciari $
 //
 // Copyright (c) 2005-2011, Matteo Cacciari, Gavin P. Salam and Gregory Soyez
 //
@@ -30,7 +30,9 @@
 #include <sstream>
 #include <algorithm>
 #include "fastjet/Selector.hh"
+#ifndef __FJCORE__
 #include "fastjet/GhostedAreaSpec.hh"  // for area support
+#endif  // __FJCORE__
 
 using namespace std;
 
@@ -130,6 +132,7 @@ void Selector::sift(const std::vector<PseudoJet> & jets,
   }
 }
 
+#ifndef __FJCORE__
 // area using default ghost area
 double Selector::area() const{
   return area(gas::def_ghost_area);
@@ -152,6 +155,7 @@ double Selector::area(double ghost_area) const{
   // check what passes the selection
   return ghost_spec.ghost_area() * ((*this)(ghosts)).size();
 }
+#endif  // __FJCORE__
 
 
 //----------------------------------------------------------------------
@@ -1339,6 +1343,7 @@ Selector SelectorIsZero(){
 
 
 //----------------------------------------------------------------------
+#ifndef __FJCORE__
 /// helper for selecting the pure ghost
 class SW_IsPureGhost : public SelectorWorker {
 public:
@@ -1364,7 +1369,6 @@ Selector SelectorIsPureGhost(){
   return Selector(new SW_IsPureGhost());
 }
 
-
 //----------------------------------------------------------------------
 // Selector and workers for obtaining a Selector from an old
 // RangeDefinition
@@ -1419,6 +1423,7 @@ protected:
 Selector::Selector(const RangeDefinition &range) {
   _worker.reset(new SW_RangeDefinition(range));
 }
+#endif  // __FJCORE__
 
 
 // operators applying directly on a Selector
